@@ -21,8 +21,7 @@
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  along with this program; if not, see <http://www.gnu.org/licenses/>.
  *
  */
 
@@ -31,7 +30,7 @@
 #include "rb-player.h"
 #include "rb-player-gst.h"
 #include "rb-player-gst-xfade.h"
-#include "rb-marshal.h"
+#include "rb-util.h"
 
 /**
  * RBPlayerPlayType:
@@ -120,7 +119,7 @@ rb_player_interface_init (RBPlayerIface *iface)
 			      G_SIGNAL_RUN_LAST | G_SIGNAL_NO_RECURSE,
 			      G_STRUCT_OFFSET (RBPlayerIface, eos),
 			      NULL, NULL,
-			      rb_marshal_VOID__POINTER_BOOLEAN,
+			      NULL,
 			      G_TYPE_NONE,
 			      2, G_TYPE_POINTER, G_TYPE_BOOLEAN);
 
@@ -140,7 +139,7 @@ rb_player_interface_init (RBPlayerIface *iface)
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (RBPlayerIface, info),
 			      NULL, NULL,
-			      rb_marshal_VOID__POINTER_INT_POINTER,
+			      NULL,
 			      G_TYPE_NONE,
 			      3, G_TYPE_POINTER, G_TYPE_INT, G_TYPE_VALUE);
 
@@ -159,7 +158,7 @@ rb_player_interface_init (RBPlayerIface *iface)
 			      G_SIGNAL_RUN_LAST | G_SIGNAL_NO_RECURSE,
 			      G_STRUCT_OFFSET (RBPlayerIface, error),
 			      NULL, NULL,
-			      rb_marshal_VOID__POINTER_POINTER,
+			      NULL,
 			      G_TYPE_NONE,
 			      2,
 			      G_TYPE_POINTER, G_TYPE_POINTER);
@@ -181,8 +180,7 @@ rb_player_interface_init (RBPlayerIface *iface)
 			      G_TYPE_FROM_INTERFACE (iface),
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (RBPlayerIface, tick),
-			      NULL, NULL,
-			      rb_marshal_VOID__POINTER_INT64_INT64,
+			      NULL, NULL, NULL,
 			      G_TYPE_NONE,
 			      3,
 			      G_TYPE_POINTER, G_TYPE_INT64, G_TYPE_INT64);
@@ -203,7 +201,7 @@ rb_player_interface_init (RBPlayerIface *iface)
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (RBPlayerIface, buffering),
 			      NULL, NULL,
-			      rb_marshal_VOID__POINTER_UINT,
+			      NULL,
 			      G_TYPE_NONE,
 			      2,
 			      G_TYPE_POINTER, G_TYPE_UINT);
@@ -227,7 +225,7 @@ rb_player_interface_init (RBPlayerIface *iface)
 			      G_SIGNAL_RUN_LAST | G_SIGNAL_DETAILED,
 			      G_STRUCT_OFFSET (RBPlayerIface, event),
 			      NULL, NULL,
-			      rb_marshal_VOID__POINTER_POINTER,
+			      NULL,
 			      G_TYPE_NONE,
 			      2,
 			      G_TYPE_POINTER, G_TYPE_POINTER);
@@ -248,7 +246,7 @@ rb_player_interface_init (RBPlayerIface *iface)
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (RBPlayerIface, playing_stream),
 			      NULL, NULL,
-			      g_cclosure_marshal_VOID__POINTER,
+			      NULL,
 			      G_TYPE_NONE,
 			      1,
 			      G_TYPE_POINTER);
@@ -266,7 +264,7 @@ rb_player_interface_init (RBPlayerIface *iface)
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (RBPlayerIface, volume_changed),
 			      NULL, NULL,
-			      g_cclosure_marshal_VOID__FLOAT,
+			      NULL,
 			      G_TYPE_NONE,
 			      1,
 			      G_TYPE_FLOAT);
@@ -286,7 +284,7 @@ rb_player_interface_init (RBPlayerIface *iface)
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (RBPlayerIface, image),
 			      NULL, NULL,
-			      rb_marshal_VOID__POINTER_OBJECT,
+			      NULL,
 			      G_TYPE_NONE,
 			      2,
 			      G_TYPE_POINTER, GDK_TYPE_PIXBUF);
@@ -305,7 +303,7 @@ rb_player_interface_init (RBPlayerIface *iface)
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (RBPlayerIface, redirect),
 			      NULL, NULL,
-			      rb_marshal_VOID__POINTER_STRING,
+			      NULL,
 			      G_TYPE_NONE,
 			      2,
 			      G_TYPE_POINTER, G_TYPE_STRING);
@@ -576,7 +574,7 @@ rb_player_multiple_open (RBPlayer *player)
  *
  * Creates a new player object.
  *
- * Return value: new player object.
+ * Return value: (transfer full): new player object.
  */
 RBPlayer*
 rb_player_new (gboolean want_crossfade, GError **error)
@@ -599,6 +597,7 @@ rb_player_new (gboolean want_crossfade, GError **error)
 void
 _rb_player_emit_eos (RBPlayer *player, gpointer stream_data, gboolean early)
 {
+	g_assert (rb_is_main_thread ());
 	g_signal_emit (player, signals[EOS], 0, stream_data, early);
 }
 
@@ -618,6 +617,7 @@ _rb_player_emit_info (RBPlayer *player,
 		      RBMetaDataField field,
 		      GValue *value)
 {
+	g_assert (rb_is_main_thread ());
 	g_signal_emit (player, signals[INFO], 0, stream_data, field, value);
 }
 
@@ -633,6 +633,7 @@ _rb_player_emit_info (RBPlayer *player,
 void
 _rb_player_emit_buffering (RBPlayer *player, gpointer stream_data, guint progress)
 {
+	g_assert (rb_is_main_thread ());
 	g_signal_emit (player, signals[BUFFERING], 0, stream_data, progress);
 }
 
@@ -648,6 +649,7 @@ _rb_player_emit_buffering (RBPlayer *player, gpointer stream_data, guint progres
 void
 _rb_player_emit_error (RBPlayer *player, gpointer stream_data, GError *error)
 {
+	g_assert (rb_is_main_thread ());
 	g_signal_emit (player, signals[ERROR], 0, stream_data, error);
 }
 
@@ -664,6 +666,7 @@ _rb_player_emit_error (RBPlayer *player, gpointer stream_data, GError *error)
 void
 _rb_player_emit_tick (RBPlayer *player, gpointer stream_data, gint64 elapsed, gint64 duration)
 {
+	g_assert (rb_is_main_thread ());
 	g_signal_emit (player, signals[TICK], 0, stream_data, elapsed, duration);
 }
 
@@ -680,6 +683,7 @@ _rb_player_emit_tick (RBPlayer *player, gpointer stream_data, gint64 elapsed, gi
 void
 _rb_player_emit_event (RBPlayer *player, gpointer stream_data, const char *name, gpointer data)
 {
+	g_assert (rb_is_main_thread ());
 	g_signal_emit (player, signals[EVENT], g_quark_from_string (name), stream_data, data);
 }
 
@@ -694,6 +698,7 @@ _rb_player_emit_event (RBPlayer *player, gpointer stream_data, const char *name,
 void
 _rb_player_emit_playing_stream (RBPlayer *player, gpointer stream_data)
 {
+	g_assert (rb_is_main_thread ());
 	g_signal_emit (player, signals[PLAYING_STREAM], 0, stream_data);
 }
 
@@ -708,6 +713,7 @@ _rb_player_emit_playing_stream (RBPlayer *player, gpointer stream_data)
 void
 _rb_player_emit_volume_changed (RBPlayer *player, float volume)
 {
+	g_assert (rb_is_main_thread ());
 	g_signal_emit (player, signals[VOLUME_CHANGED], 0, volume);
 }
 
@@ -723,6 +729,7 @@ _rb_player_emit_volume_changed (RBPlayer *player, float volume)
 void
 _rb_player_emit_image (RBPlayer *player, gpointer stream_data, GdkPixbuf *image)
 {
+	g_assert (rb_is_main_thread ());
 	g_signal_emit (player, signals[IMAGE], 0, stream_data, image);
 }
 
@@ -738,6 +745,7 @@ _rb_player_emit_image (RBPlayer *player, gpointer stream_data, GdkPixbuf *image)
 void
 _rb_player_emit_redirect (RBPlayer *player, gpointer stream_data, const char *uri)
 {
+	g_assert (rb_is_main_thread ());
 	g_signal_emit (player, signals[REDIRECT], 0, stream_data, uri);
 }
 
